package handlers

import (
	"html/template"
	"log/slog"
	"net/http"
	"os"
)

var log *slog.Logger

func init() {
	log = slog.New(slog.NewJSONHandler(os.Stderr, &slog.HandlerOptions{
		Level:     slog.LevelDebug,
		AddSource: true,
	}))
}

var roundWords = map[string]string{
	"hamster":   "blue",
	"child":     "red",
	"wheel":     "white",
	"condition": "black",
	"test":      "white",
}

func HandlePing(w http.ResponseWriter, r *http.Request) {
	w.Write([]byte("pong"))
}

func HandleHome(w http.ResponseWriter, r *http.Request) {
	tmpl, err := template.ParseGlob("components/*.html")
	if err != nil {
		abortWithError(w, err.Error())
		return
	}
	tmpl.ExecuteTemplate(w, "main", roundWords)
}
